@@ -18,11 +18,11 @@ def load_paras(filepath: str) -> List[str]:
     try:
         text = Path(filepath).read_text("utf-8")
     except Exception as exc:
-        logger.warning("Path read_text('utf-8') exc: %s", exc)
+        # logger.warning("Path read_text('utf-8') exc: %s", exc)
         try:
             text = Path(filepath).read_text("gbk")
         except Exception as exc:  # pylint: disable=try-except-raise
-            logger.warning("Path read_text('gbk') exc: %s", exc)
+            # logger.warning("Path read_text('gbk') exc: %s", exc)
             _ = chardet.detect(Path(filepath).read_bytes()[:5000])
             encoding = _.get("encoding", "utf8")
             try:
